@@ -28,7 +28,7 @@ static const unsigned long _glibtop_sysdeps_swap = 0;
 /* Init function. */
 
 void
-glibtop_init_swap_s (glibtop *server)
+_glibtop_init_swap_s (glibtop *server)
 {
 	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
